@@ -1,4 +1,4 @@
-from .data import DataManager
+from .data import DataManager, DatamanagerBuilder
 from .evaluator import ClassificationEvaluator, ClassificationMultiLabelEvaluator, MultiLabelEvaluator
 from .evaluator import ClassificationMultiClassEvaluator, MultiClassEvaluator
 from .evaluator import DetectionEvaluator
