@@ -45,6 +45,10 @@ def get_non_zero_parts(signal):
     assert len(starts) == len(ends)
     return starts, ends
 
+def get_zero_parts(signal):
+    signal = np.array(signal) == 0
+    assert signal.ndim == 1
+    return get_non_zero_parts(signal)
 
 def find_longest_start_end(arr):
     substr = max(re.findall('1+', str(arr)))
