@@ -729,12 +729,15 @@ def scatter3d(xyz_data_list, label_list, xyz_label=None, title='3d Scatter plot'
     pass
 
 
-def scatter2d(xy_data_list, label_list, xy_label=None, title='2d Scatter plot'):
+def scatter2d(xy_data_list, label_list=None, xy_label=None, title='2d Scatter plot'):
     if not xy_data_list:
         return
     xyz_data = np.array(xy_data_list)
     assert xyz_data.ndim == 2
     assert xyz_data.shape[1] == 2
+    
+    if label_list is None:
+        label_list = [0] * len(xy_data_list)
 
     label_set = set(label_list)
     label_2_color_dict = dict()
@@ -1018,7 +1021,7 @@ def image_border_move(img, left, top=None, right=None, bottom=None, border_type=
             border_type_index = cv2.BORDER_REFLECT_101
         else:
             raise RuntimeError(f"unknown border type {border_type}.")
-        padded_img = cv2.copyMakeBorder(img, padding_data[1], padding_data[3], padding_data[0], padding_data[2], borderType=border_type_index, value=value)
+        padded_img = cv2.copyMakeBorder(img, padding_data[1], padding_data[3], padding_data[0], padding_data[2], borderType=border_type_index, value=[value] * 4)
     else:
         padded_img = img
 
