@@ -19,12 +19,10 @@ def single_process(main_fun, paras, share_list, share_lock, total_size, start_ti
             return
     else:
         res = main_fun(paras)
-    if res is not None:
-        share_lock.acquire()
-        share_list.append(res)
-        share_lock.release()
-    else:
-        print("None res got, and it won't appear in the share_list. ")
+
+    share_lock.acquire()
+    share_list.append(res)
+    share_lock.release()
 
     print(f"{len(share_list)} / {total_size}")
     
